@@ -1,32 +1,29 @@
 #!/usr/bin/perl
 
+use HTML::Merge::Development;
 use CGI qw/:standard/;
 use strict;
 
-my $MERGE_ABSOLUTE_PATH = param('merge_absolute_path');
-my $MERGE_SCRIPT = param('merge_script');
-
-my $file = "$MERGE_ABSOLUTE_PATH/$MERGE_SCRIPT";
-$file =~ s/\.\w+$/.conf/;
-
-do $file;
+ReadConfig();
 
 my $log_dir = "$HTML::Merge::Ini::MERGE_ABSOLUTE_PATH/$HTML::Merge::Ini::MERGE_ERROR_LOG_PATH/$ENV{'REMOTE_ADDR'}";
 
 die "Not in web mode" if (length($log_dir) < 6);
 
-&recur($log_dir);
+use File::Path;
+rmtree $log_dir;
 
 print <<HTML;
 Content-type: text/html
 
 <HTML>
-<BODY onLoad="window.close();">
+<BODY onLoad="opener.focus(); window.close();">
 </BODY>
 </HTML>
 HTML
 
 sub recur {
+	die "Obsolete";
         my $dir = shift;
         foreach (glob("$dir/*")) {
                 if (-d $_) {
